emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

emacs-27 6290850: Consistently stylize eldoc as ElDoc in prose


From: Basil L. Contovounesios
Subject: emacs-27 6290850: Consistently stylize eldoc as ElDoc in prose
Date: Fri, 10 Jul 2020 10:30:02 -0400 (EDT)

branch: emacs-27
commit 6290850dac130521551913ce78671fcccfe5c0f3
Author: Basil L. Contovounesios <contovob@tcd.ie>
Commit: Basil L. Contovounesios <contovob@tcd.ie>

    Consistently stylize eldoc as ElDoc in prose
    
    * doc/emacs/custom.texi (Specifying File Variables):
    * doc/emacs/modes.texi (Major Modes):
    * doc/emacs/programs.texi (Lisp Doc):
    * etc/NEWS.22:
    * etc/NEWS.23:
    * lisp/progmodes/python.el:
    (python-eldoc-function):
    * test/lisp/progmodes/python-tests.el: Consistently capitalize eldoc
    as ElDoc rather than Eldoc.
---
 doc/emacs/custom.texi               | 2 +-
 doc/emacs/modes.texi                | 2 +-
 doc/emacs/programs.texi             | 8 ++++----
 etc/NEWS.22                         | 2 +-
 etc/NEWS.23                         | 2 +-
 lisp/progmodes/python.el            | 8 ++++----
 test/lisp/progmodes/python-tests.el | 2 +-
 7 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/doc/emacs/custom.texi b/doc/emacs/custom.texi
index d034a78..719e09e 100644
--- a/doc/emacs/custom.texi
+++ b/doc/emacs/custom.texi
@@ -1223,7 +1223,7 @@ other context has no special meaning.
 disable a minor mode in a local variables list, use the @code{eval}
 keyword with a Lisp expression that runs the mode command
 (@pxref{Minor Modes}).  For example, the following local variables
-list enables Eldoc mode (@pxref{Lisp Doc}) by calling
+list enables ElDoc mode (@pxref{Lisp Doc}) by calling
 @code{eldoc-mode} with no argument (calling it with an argument of 1
 would do the same), and disables Font Lock mode (@pxref{Font Lock}) by
 calling @code{font-lock-mode} with an argument of @minus{}1.
diff --git a/doc/emacs/modes.texi b/doc/emacs/modes.texi
index c1420ea..c9c175d 100644
--- a/doc/emacs/modes.texi
+++ b/doc/emacs/modes.texi
@@ -126,7 +126,7 @@ see which mode is actually being entered.
   Mode hooks are commonly used to enable minor modes (@pxref{Minor
 Modes}).  For example, you can put the following lines in your init
 file to enable Flyspell minor mode in all text-based major modes
-(@pxref{Spelling}), and Eldoc minor mode in Emacs Lisp mode
+(@pxref{Spelling}), and ElDoc minor mode in Emacs Lisp mode
 (@pxref{Lisp Doc}):
 
 @example
diff --git a/doc/emacs/programs.texi b/doc/emacs/programs.texi
index 683374c..b976f2e 100644
--- a/doc/emacs/programs.texi
+++ b/doc/emacs/programs.texi
@@ -1260,16 +1260,16 @@ the WoMan Info manual, which is distributed with Emacs.
 to view the built-in documentation for the Lisp functions and
 variables that you want to use.  @xref{Name Help}.
 
-@cindex Eldoc mode
+@cindex ElDoc mode
 @findex eldoc-mode
 @findex global-eldoc-mode
-  Eldoc is a buffer-local minor mode that helps with looking up Lisp
+  ElDoc is a buffer-local minor mode that helps with looking up Lisp
 documentation.  When it is enabled, the echo area displays some useful
 information whenever there is a Lisp function or variable at point;
 for a function, it shows the argument list, and for a variable it
 shows the first line of the variable's documentation string.  To
-toggle Eldoc mode, type @kbd{M-x eldoc-mode}.  There's also a Global
-Eldoc mode, which is turned on by default, and affects buffers, such
+toggle ElDoc mode, type @kbd{M-x eldoc-mode}.  There's also a Global
+ElDoc mode, which is turned on by default, and affects buffers, such
 as @samp{*scratch*}, whose major mode is Emacs Lisp or Lisp
 Interaction (@w{@kbd{M-x global-eldoc-mode}} to turn it off globally).
 
diff --git a/etc/NEWS.22 b/etc/NEWS.22
index 548a73a..4df1792 100644
--- a/etc/NEWS.22
+++ b/etc/NEWS.22
@@ -5239,7 +5239,7 @@ has no effect on systems with case-insensitive file names.
 hooks.  `run-mode-hooks' does this automatically.
 
 *** Major modes can define `eldoc-documentation-function'
-locally to provide Eldoc functionality by some method appropriate to
+locally to provide ElDoc functionality by some method appropriate to
 the language.
 
 *** Use the new function `run-mode-hooks' to run the major mode's mode hook.
diff --git a/etc/NEWS.23 b/etc/NEWS.23
index 9a49a7d..331ed28 100644
--- a/etc/NEWS.23
+++ b/etc/NEWS.23
@@ -1779,7 +1779,7 @@ to update it to the new VC.
 If `default-directory' is a remote file name, subprocesses are started
 on the corresponding remote system.
 
-*** Eldoc highlights the function argument under point
+*** ElDoc highlights the function argument under point
 with the face `eldoc-highlight-function-argument'.
 
 *** In Etags, the --members option is now the default.
diff --git a/test/lisp/progmodes/python-tests.el 
b/test/lisp/progmodes/python-tests.el
index 65a60b4..f57150c 100644
--- a/test/lisp/progmodes/python-tests.el
+++ b/test/lisp/progmodes/python-tests.el
@@ -3554,7 +3554,7 @@ def foo():
 ;;; Code check
 
 
-;;; Eldoc
+;;; ElDoc
 
 (ert-deftest python-eldoc--get-symbol-at-point-1 ()
   "Test paren handling."



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/progmodes/python.el b/lisp/progmodes/python.el
index 107b291..785b941 100644
--- a/lisp/progmodes/python.el
+++ b/lisp/progmodes/python.el
@@ -34,7 +34,7 @@
 ;; Implements Syntax highlighting, Indentation, Movement, Shell
 ;; interaction, Shell completion, Shell virtualenv support, Shell
 ;; package support, Shell syntax highlighting, Pdb tracking, Symbol
 ;; completion, Skeletons, FFAP, Code Check, Eldoc, Imenu.
 
 ;; Syntax highlighting: Fontification of code is provided and supports
 ;; python's triple quoted strings properly.
@@ -216,7 +216,7 @@
 ;; Code check: Check the current file for errors with `python-check'
 ;; using the program defined in `python-check-command'.
 
 ;; Eldoc: returns documentation for object at point by using the
 ;; inferior python subprocess to inspect its documentation.  As you
 ;; might guessed you should run `python-shell-send-buffer' from time
 ;; to time to get better results too.
@@ -4461,7 +4461,7 @@ See `python-check-command' for the default."
                          (format python-check-buffer-name command)))))
 
 
-;;; Eldoc
+;;; ElDoc
 
 (defcustom python-eldoc-setup-code
   "def __PYDOC_get_help(obj):
@@ -4578,7 +4578,7 @@ fetching."
     (with-timeout (python-eldoc-function-timeout
                    (if python-eldoc-function-timeout-permanent
                        (progn
-                         (message "Eldoc echo-area display muted in this 
buffer, see `python-eldoc-function'")
+                         (message "ElDoc echo-area display muted in this 
buffer, see `python-eldoc-function'")
                          (setq python-eldoc-get-doc nil))
                      (message "`python-eldoc-function' timed out, see 
@@ -34,7 +34,7 @@
 ;; interaction, Shell completion, Shell virtualenv support, Shell
 ;; package support, Shell syntax highlighting, Pdb tracking, Symbol
-;; completion, Skeletons, FFAP, Code Check, Eldoc, Imenu.
+;; completion, Skeletons, FFAP, Code Check, ElDoc, Imenu.
 
 ;; Syntax highlighting: Fontification of code is provided and supports
@@ -216,7 +216,7 @@
 ;; using the program defined in `python-check-command'.
 
-;; Eldoc: returns documentation for object at point by using the
+;; ElDoc: returns documentation for object at point by using the
 ;; inferior python subprocess to inspect its documentation.  As you
 ;; might guessed you should run `python-shell-send-buffer' from time
`python-eldoc-function-timeout'")))
       (python-eldoc--get-doc-at-point))))